@@ -1,15 +1,27 @@
+// Some libraries define HOST_NOT_FOUND.  Make sure we can still compile fine
+// even if this is the case:
+#define HOST_NOT_FOUND 1
+
 #include <giomm.h>
 #include <iostream>
 #include <string.h>
 
-int main(int argc, char** argv)
+// This is just to test a workaround in the error.h header.  We save and #undef
+// HOST_NOT_FOUND if it was defined by another header, and then restore it at
+// the end of the header.  Here I'm just making sure that our temporary value
+// doesn't remain set
+#ifdef GIOMM_SAVED_HOST_NOT_FOUND
+#error Forgot to #undef GIOMM_SAVED_HOST_NOT_FOUND
+#endif
+
+int main(int, char**)
 {
   Glib::init();
   Gio::init();
 
   try
   {
-    Glib::RefPtr<Gio::File> file = Gio::File::create_for_path("/home/murrayc/test.txt");
+    Glib::RefPtr<Gio::File> file = Gio::File::create_for_path("/etc/fstab");
     if(!file)
       std::cerr << "Gio::File::create_for_path() returned an empty RefPtr." << std::endl;
 
@@ -18,14 +30,13 @@ int main(int argc, char** argv)
       std::cerr << "Gio::File::read() returned an empty RefPtr." << std::endl;
 
     gchar buffer[1000]; //TODO: This is unpleasant.
-    memset(buffer, 0, 1000);
-    const gsize bytes_read = stream->read(buffer, 1000);
-    
+    memset(buffer, 0, sizeof buffer);
+    const gsize bytes_read = stream->read(buffer, sizeof buffer - 1);
+
     if(bytes_read)
       std::cout << "File contents read: " << buffer << std::endl;
     else
       std::cerr << "Gio::InputStream::read() read 0 bytes." << std::endl;
-
   }
   catch(const Gio::Error& ex)
   {
@@ -44,7 +55,6 @@ int main(int argc, char** argv)
     std::cerr << "Exception caught: " << ex.what() << std::endl; 
   }
 
-
   return 0;
 }
 
